@@ -39,6 +39,7 @@
 #include <KConfigGroup>
 #include <KEditToolBar>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <KSharedConfig>
 
 #include <QDBusConnection>
@@ -60,6 +61,7 @@ KEBApp::KEBApp(const QString &bookmarksFile, bool readonly, const QString &addre
     connect(m_cmdHistory, &CommandHistory::notifyCommandExecuted, this, &KEBApp::notifyCommandExecuted);
 
     GlobalBookmarkManager::self()->createManager(m_bookmarksFilename, m_dbusObjectName, m_cmdHistory);
+    connect(GlobalBookmarkManager::self(), &GlobalBookmarkManager::error, this, &KEBApp::slotManagerError);
 
     s_topLevel = this;
 
@@ -301,18 +303,10 @@ static bool lessAddress(const QString &first, const QString &second)
         uint bNext = b.indexOf(QLatin1String("/"), bLast + 1);
 
         bool okay;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        uint aNum = a.midRef(aLast + 1, aNext - aLast - 1).toUInt(&okay);
-#else
         uint aNum = QStringView(a).mid(aLast + 1, aNext - aLast - 1).toUInt(&okay);
-#endif
         if (!okay)
             return false;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        uint bNum = b.midRef(bLast + 1, bNext - bLast - 1).toUInt(&okay);
-#else
         uint bNum = QStringView(b).mid(bLast + 1, bNext - bLast - 1).toUInt(&okay);
-#endif
         if (!okay)
             return true;
 
@@ -450,7 +444,12 @@ void KEBApp::slotNewToolbarConfig()
 {
     // called when OK or Apply is clicked
     createGUI();
-    applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), "MainWindow"));
+    applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("MainWindow")));
+}
+
+void KEBApp::slotManagerError(const QString &errorMessage)
+{
+    KMessageBox::error(this, errorMessage);
 }
 
 /* -------------------------- */
